@@ -452,6 +452,16 @@ class GroupAPI(BaseAPI):
         status = APIReturnStatus(result)
         return status.data
 
+    async def get_group_list(self, info: bool = False) -> list[Union[str, dict]]:
+        result = await self.async_callback("/get_group_list", {"next_token": ""})
+        status = APIReturnStatus(result)
+        if status.is_success():
+            if info:
+                return status.data
+            return [str(group.get("group_id")) for group in status.data]
+        else:
+            return []
+
     async def get_group_member_info(
         self, group_id: Union[str, int], user_id: Union[str, int]
     ) -> GroupMemberInfo:
@@ -507,7 +517,7 @@ class GroupAPI(BaseAPI):
     async def set_group_name(self, group_id: Union[str, int], name: str) -> None:
         """设置群名"""
         result = await self.async_callback(
-            "/set_group_name", {"group_id": group_id, "name": name}
+            "/set_group_name", {"group_id": group_id, "group_name": name}
         )
         APIReturnStatus.raise_if_failed(result)
 
