@@ -48,6 +48,17 @@ class MessageAPI(BaseAPI):
         status = MessageAPIReturnStatus(result)
         return status.message_id
 
+    async def post_all_group_array_msg(self, msg: MessageArray) -> List[int]:
+        """发送群聊消息到所有群（NcatBot 接口）
+        慎用！！！
+        """
+        group_id_list = await self.get_group_list()
+        message_id_list = []
+        for group_id in group_id_list:
+            message_id = await self.post_group_array_msg(group_id, msg)
+            message_id_list.append(message_id)
+        return message_id_list
+
     async def post_group_msg(
         self,
         group_id: Union[str, int],
@@ -71,6 +82,30 @@ class MessageAPI(BaseAPI):
             msg_array += rtf
         return await self.post_group_array_msg(group_id, msg_array)
 
+    async def post_all_group_msg(
+        self,
+        text: Optional[str] = None,
+        at: Optional[Union[str, int]] = None,
+        reply: Optional[Union[str, int]] = None,
+        image: Optional[str] = None,
+        rtf: Optional[MessageArray] = None,
+    ) -> list[int]:
+        """发送群聊消息到所有群（NcatBot 接口）
+        慎用！！！
+        """
+        msg_array = MessageArray()
+        if reply is not None:
+            msg_array.add_reply(reply)
+        if at is not None:
+            msg_array.add_at(at)
+        if text is not None:
+            msg_array.add_text(text)
+        if image is not None:
+            msg_array.add_image(image)
+        if rtf is not None:
+            msg_array += rtf
+        return await self.post_all_group_array_msg(msg_array)
+
     async def send_group_text(self, group_id: Union[str, int], text: str) -> str:
         """发送群聊文本消息（支持 CQ 码）（NcatBot 接口）"""
         msg_array = MessageArray(text)
@@ -425,14 +460,37 @@ class MessageAPI(BaseAPI):
     # ---------------------
 
     async def send_poke(
-        self, group_id: Optional[Union[str, int]] = None, user_id: Optional[Union[str, int]] = None
+        self,
+        user_id: Union[str, int],
+        group_id: Optional[Union[str, int]] = None,
     ) -> None:
-        """发送戳一戳消息"""
-        check_exclusive_argument(group_id, user_id, ["group_id", "user_id"], error=True)
-        if user_id:
-            result = await self.async_callback("/friend_poke", {"user_id": user_id})
+        """
+        发送戳一戳消息
+
+        根据是否提供 group_id 参数来决定发送群戳一戳还是好友戳一戳。
+        如果提供了 group_id，则在指定群内戳指定用户；
+        如果未提供 group_id 或 group_id 为 None，则直接戳好友。
+
+        Args:
+            user_id (Union[str, int]): 要戳的用户ID，必须提供且不能为空
+            group_id (Optional[Union[str, int]], 可选): 群号，如果提供则在群内戳一戳，
+                如果不提供则发送好友戳一戳. Defaults to None.
+
+        Raises:
+            NcatBotValueError: 当 user_id 为空时抛出
+            NapCatAPIError: 当API调用失败时抛出
+
+        Returns:
+            None: 该方法无返回值
+        """
+        if not user_id:
+            raise NcatBotValueError("user_id", user_id, must_be=False)
+        if group_id:
+            result = await self.async_callback(
+                "/group_poke", {"group_id": group_id, "user_id": user_id}
+            )
         else:
-            result = await self.async_callback("/group_poke", {"group_id": group_id})
+            result = await self.async_callback("/friend_poke", {"user_id": user_id})
         APIReturnStatus.raise_if_failed(result)
 
     async def delete_msg(self, message_id: Union[str, int]) -> dict:
@@ -805,9 +863,9 @@ class MessageAPI(BaseAPI):
         return run_coroutine(self.friend_poke, user_id)
 
     def send_poke_sync(
-        self, group_id: Union[str, int] = None, user_id: Union[str, int] = None
+        self, user_id: Union[str, int], group_id: Optional[Union[str, int]] = None
     ) -> None:
-        return run_coroutine(self.send_poke, group_id, user_id)
+        return run_coroutine(self.send_poke, user_id, group_id)
 
     def delete_msg_sync(self, message_id: Union[str, int]) -> dict:
         return run_coroutine(self.delete_msg, message_id)
